==> jangaroo-sdk-0.9.3.zip: joo/classes/ext/config/dragsource.js <==
joo.classLoader.prepare("package ext.config",/* {

import joo.JavaScriptObject;*/

/**
 * A simple class that provides the basic implementation needed to make any element draggable.
 *
 * <p>This class serves as a
 * typed config object for constructor of class DragSource.</p>
 *
 * <p>Copyright &#169; 2011 Sencha Inc.</p>
 * @see ext.dd.DragSource
 */
{ExtConfig:{target:"ext.dd.DragSource"}},
"public class dragsource extends joo.JavaScriptObject",2,function($$private){;return[ 

  "public function dragsource",function dragsource$(config/*:Object = null*/) {if(arguments.length<1){config = null;}

    joo.JavaScriptObject.call(this,config);
  },


  /**
   A named drag drop group to which this object belongs. If a group is specified, then this object will only interact with other drag drop objects in the same group (defaults to undefined).
   */
  "public native function get ddGroup"/*():String*/,

  /**
   * @private
   */
  "public native function set ddGroup"/*(value:String):void*/,

  /**
   The CSS class returned to the drag source when drop is allowed (defaults to "x-dd-drop-ok").
   */
  "public native function get dropAllowed"/*():String*/,

  /**
   * @private
   */
  "public native function set dropAllowed"/*(value:String):void*/,

  /**
   The CSS class returned to the drag source when drop is not allowed (defaults to "x-dd-drop-nodrop").
   */
  "public native function get dropNotAllowed"/*():String*/,

  /**
   * @private
   */
  "public native function set dropNotAllowed"/*(value:String):void*/,


];},[],["joo.JavaScriptObject"], "0.8.0", "0.9.3"
);

==> jangaroo-sdk-0.9.13.zip: joo/classes/ext/config/dragsource.js <==
joo.classLoader.prepare("package ext.config",/* {

import joo.JavaScriptObject;*/

/**
 * A simple class that provides the basic implementation needed to make any element draggable.
 *
 * <p>This class serves as a
 * typed config object for constructor of class DragSource.</p>
 *
 * <p>Copyright &#169; 2011 Sencha Inc.</p>
 * @see ext.dd.DragSource
 */
{ExtConfig:{target:"ext.dd.DragSource"}},
"public class dragsource extends joo.JavaScriptObject",2,function($$private){var $1=joo;return[ 

  "public function dragsource",function dragsource(config/*:Object = null*/) {if(arguments.length<=0)config=null;

     $1.JavaScriptObject.call(this,config);
  },


  /**
   A named drag drop group to which this object belongs. If a group is specified, then this object will only interact with other drag drop objects in the same group (defaults to undefined).
   */
  "public native function get ddGroup"/*():String*/,

  /**
   * @private
   */
  "public native function set ddGroup"/*(value:String):void*/,

  /**
   The CSS class returned to the drag source when drop is allowed (defaults to "x-dd-drop-ok").
   */
  "public native function get dropAllowed"/*():String*/,

  /**
   * @private
   */
  "public native function set dropAllowed"/*(value:String):void*/,

  /**
   The CSS class returned to the drag source when drop is not allowed (defaults to "x-dd-drop-nodrop").
   */
  "public native function get dropNotAllowed"/*():String*/,

  /**
   * @private
   */
  "public native function set dropNotAllowed"/*(value:String):void*/,


undefined];},[],["joo.JavaScriptObject"], "0.8.0", "0.9.12"
);
